Core API Basics — SQLAlchemy 1.0 Documentation

Release: 1.0.7 | Release Date: July 20, 2015

# SQLAlchemy 1.0 Documentation

# Core API Basics

- Events
  - Event Registration
  - Named Argument Styles
  - Targets
  - Modifiers
  - Event Reference
  - API Reference
- Runtime Inspection API
  - Available Inspection Targets
- Deprecated Event Interfaces
  - Execution, Connection and Cursor Events
  - Connection Pool Events
- Core Exceptions
- Core Internals